pub fn get_new_liquid(
world: &Arc<World>,
pos: BlockPos,
state: BlockStateId,
fluid_id: FluidRef,
drop_off: u8,
) -> FluidStateExpand description
Calculates the new fluid state at a position based on neighbors.
pub fn get_new_liquid(
world: &Arc<World>,
pos: BlockPos,
state: BlockStateId,
fluid_id: FluidRef,
drop_off: u8,
) -> FluidStateCalculates the new fluid state at a position based on neighbors.